@@ -73,8 +73,8 @@ from DLStudio import *
 import os, sys
 
 
-dataroot = "./dataGAN/PurdueShapes5GAN/multiobj/"
-#dataroot =  "/home/kak/ImageDatasets/PurdueShapes5GAN/multiobj/"
+#dataroot = "./dataGAN/PurdueShapes5GAN/multiobj/"
+dataroot =  "/home/kak/ImageDatasets/PurdueShapes5GAN/multiobj/"
 #dataroot = "/mnt/cloudNAS3/Avi/ImageDatasets/PurdueShapes5GAN/multiobj/"
 
 
@@ -153,7 +153,7 @@ vqvae  =  DLStudio.VQVAE(
           
 
 number_of_learnable_params_in_vqvae = sum(p.numel() for p in vqvae.parameters() if p.requires_grad)
-print("\n\nThe number of learnable parameters in VAE: %d" % number_of_learnable_params_in_vqvae)
+print("\n\nThe number of learnable parameters in VQVAE: %d" % number_of_learnable_params_in_vqvae)
 
 vqvae.set_dataloader()
 
