@@ -74,14 +74,11 @@ model = segmenter.mUNet(skip_connections=True, depth=16)
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d\n" % number_of_learnable_params)
 
-num_layers = len(list(model.parameters()))
-print("\nThe number of layers in the model: %d\n\n" % num_layers)
-
-
 segmenter.run_code_for_training_for_semantic_segmentation(model)
 
-import pymsgbox
-response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
-if response == "OK": 
-    segmenter.run_code_for_testing_semantic_segmentation(model)
+#import pymsgbox
+#response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
+#if response == "OK": 
+
+segmenter.run_code_for_testing_semantic_segmentation(model)
 
