@@ -30,9 +30,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 
 from DLStudio import *
 
-#dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
 dataroot = "./data/TextDatasets/sentiment_dataset/"
-
+#dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
 
 dataset_archive_train = "sentiment_dataset_train_40.tar.gz"
 #dataset_archive_train = "sentiment_dataset_train_200.tar.gz"
@@ -77,10 +76,6 @@ text_cl.load_SentimentAnalysisDataset(dataserver_train, dataserver_test)
 model = text_cl.GRUnetWithEmbeddings(input_size=300, hidden_size=100, output_size=2, num_layers=2)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-
-num_layers = len(list(model.parameters()))
-
-print("\n\nThe number of layers in the model: %d" % num_layers)
 print("\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 
 ## TRAINING:
