@@ -77,17 +77,17 @@ vocab_size = dataserver_train.get_vocab_size()
 model = text_cl.TEXTnetOrder2(vocab_size, hidden_size=512, output_size=2)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-num_layers = len(list(model.parameters()))
 
-print("\n\nThe number of layers in the model: %d" % num_layers)
 print("\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
+
 print("\nThe size of the vocabulary (which is also the size of the one-hot vecs for words): %d\n\n" % vocab_size)
 
 text_cl.run_code_for_training_with_TEXTnetOrder2(model, display_train_loss=True)
 
-import pymsgbox
-response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
-if response == "OK": 
-    text_cl.run_code_for_testing_with_TEXTnetOrder2(model)
+#import pymsgbox
+#response = pymsgbox.confirm("Finished training.  Start testing on unseen data?")
+#if response == "OK": 
+
+text_cl.run_code_for_testing_with_TEXTnetOrder2(model)
 
 
