@@ -79,9 +79,9 @@ from AdversarialLearning import *
 import sys
 
 dls = DLStudio(                                                                                       
-                  dataroot = "./dataGAN/PurdueShapes5GAN/multiobj/", 
+#                  dataroot = "./dataGAN/PurdueShapes5GAN/multiobj/", 
 #                  dataroot = "/mnt/cloudNAS3/Avi/ImageDatasets/PurdueShapes5GAN/multiobj/",
-#                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5GAN/multiobj/",  
+                  dataroot = "/home/kak/ImageDatasets/PurdueShapes5GAN/multiobj/",  
                   image_size = [64,64],                                                               
                   path_saved_model = "./saved_model", 
                   learning_rate = 1e-4,       ## <==  try smaller value if mode collapse
